==> org.simantics.graph.compiler.source_1.1.15.v20170529-110655.jar: org/simantics/graph/compiler/internal/templates/LoadDataValueTemplate.java <==
package org.simantics.graph.compiler.internal.templates;

import java.io.IOException;
import java.util.Collection;

import org.simantics.databoard.Bindings;
import org.simantics.databoard.binding.mutable.Variant;
import org.simantics.databoard.serialization.Serializer;
import org.simantics.graph.compiler.ExternalFileLoader;
import org.simantics.graph.compiler.internal.store.LocationStore;
import org.simantics.graph.compiler.internal.store.PreValueStore;
import org.simantics.graph.query.IGraph;
import org.simantics.graph.store.GraphStore;
import org.simantics.ltk.Location;
import org.simantics.ltk.Problem;

public enum LoadDataValueTemplate implements ITemplate {
	INSTANCE;
	
	@Override
	public void apply(IGraph graph, GraphStore store,
			int[] parameters, ExternalFileLoader fileLoader, Collection<Problem> problems) {
		String fileName = store.getStore(PreValueStore.class).getStringValue(parameters[1]);
		if(fileName == null) {
			Location location = store.getStore(LocationStore.class)
			.getLocation(parameters[1]);
			problems.add(new Problem(
				location, "Expected a string"));
		}		
		try {
		    byte[] bytes = fileLoader.load(fileName);
		    Serializer variantSerializer = Bindings.getSerializerUnchecked(Bindings.VARIANT);
		    Variant value = (Variant)variantSerializer.deserialize(bytes);
			store.values.setValue(parameters[0], value);
		} catch (IOException e) {
			Location location = store.getStore(LocationStore.class)
				.getLocation(parameters[1]);
			problems.add(new Problem(
				location, e.getMessage()));
		}		
	}

}

==> org.simantics.graph.compiler.source_1.1.20.v20251104-215234.jar: org/simantics/graph/compiler/internal/templates/LoadDataValueTemplate.java <==
package org.simantics.graph.compiler.internal.templates;

import java.io.IOException;
import java.util.Collection;

import org.simantics.databoard.Bindings;
import org.simantics.databoard.binding.mutable.Variant;
import org.simantics.databoard.serialization.Serializer;
import org.simantics.graph.compiler.ExternalFileLoader;
import org.simantics.graph.compiler.internal.ltk.Location;
import org.simantics.graph.compiler.internal.ltk.Problem;
import org.simantics.graph.compiler.internal.store.LocationStore;
import org.simantics.graph.compiler.internal.store.PreValueStore;
import org.simantics.graph.query.IGraph;
import org.simantics.graph.store.GraphStore;

public enum LoadDataValueTemplate implements ITemplate {
	INSTANCE;
	
	@Override
	public void apply(IGraph graph, GraphStore store,
			int[] parameters, ExternalFileLoader fileLoader, Collection<Problem> problems) {
		String fileName = store.getStore(PreValueStore.class).getStringValue(parameters[1]);
		if(fileName == null) {
			Location location = store.getStore(LocationStore.class)
			.getLocation(parameters[1]);
			problems.add(new Problem(
				location, "Expected a string"));
		}		
		try {
		    byte[] bytes = fileLoader.load(fileName);
		    Serializer variantSerializer = Bindings.getSerializerUnchecked(Bindings.VARIANT);
		    Variant value = (Variant)variantSerializer.deserialize(bytes);
			store.values.setValue(parameters[0], value);
		} catch (IOException e) {
			Location location = store.getStore(LocationStore.class)
				.getLocation(parameters[1]);
			problems.add(new Problem(
				location, e.getMessage()));
		}		
	}

}
